@@ -184,7 +184,7 @@ UCUnits::UCUnits(QObject *parent) :
         QObject::connect(nativeInterface, &QPlatformNativeInterface::windowPropertyChanged,
                          this, &UCUnits::windowPropertyChanged);
         QScreen* screen = referenceScreen();
-        if (screen) {
+        if (screen && nativeInterface->nativeResourceForScreen("scale", screen)) {
             float scale = getScreenScaling(screen);
             if (scale > 0.0f)
                 m_gridUnit = DEFAULT_GRID_UNIT_PX * scale;
@@ -266,8 +266,8 @@ QString UCUnits::resolveResource(const QUrl& url)
         }
     }
 
-    const QString prefix = fileInfo.dir().absolutePath() + "/" + fileInfo.baseName();
-    const QString suffix = "." + fileInfo.completeSuffix();
+    const QString prefix = fileInfo.dir().absolutePath() + QStringLiteral("/") + fileInfo.baseName();
+    const QString suffix = QStringLiteral(".") + fileInfo.completeSuffix();
 
     /* Use file with expected grid unit suffix if it exists.
        For example, if m_gridUnit = 10, look for resource@10.png.
@@ -295,7 +295,7 @@ QString UCUnits::resolveResource(const QUrl& url)
        than resource@18.png.
     */
     QStringList nameFilters;
-    nameFilters << fileInfo.baseName() + "@[0-9]*" + suffix;
+    nameFilters << fileInfo.baseName() + QStringLiteral("@[0-9]*") + suffix;
     const QStringList files = fileInfo.dir().entryList(nameFilters, QDir::Files);
 
     if (!files.empty()) {
@@ -311,7 +311,7 @@ QString UCUnits::resolveResource(const QUrl& url)
 
         path = prefix + suffixForGridUnit(selectedGridUnitSuffix) + suffix;
         float scaleFactor = m_gridUnit / selectedGridUnitSuffix;
-        return QString::number(scaleFactor) + "/" + path;
+        return QString::number(scaleFactor) + QStringLiteral("/") + path;
     }
 
     return QString();
@@ -319,7 +319,7 @@ QString UCUnits::resolveResource(const QUrl& url)
 
 QString UCUnits::suffixForGridUnit(float gridUnit)
 {
-    return "@" + QString::number(gridUnit);
+    return QStringLiteral("@") + QString::number(gridUnit);
 }
 
 float UCUnits::gridUnitSuffixFromFileName(const QString& fileName)
